pub unsafe fn drop_buffer(buf: *mut FolditPluginBuffer)Expand description
Release a buffer previously produced by buffer_from_vec.
Safety
buf must be null or point to a buffer this plugin allocated.
pub unsafe fn drop_buffer(buf: *mut FolditPluginBuffer)Release a buffer previously produced by buffer_from_vec.
buf must be null or point to a buffer this plugin allocated.