drop_error

Function drop_error 

pub unsafe fn drop_error(err: *mut FolditPluginError)
Release both inner buffers of an error this plugin allocated.

Safety

err must be null or point to an error this plugin allocated.