#[repr(i32)]pub enum ConnectionType {
Unspecified = 0,
Hbond = 1,
Disulfide = 2,
Clash = 3,
Band = 4,
}Expand description
Kind of structural connection between two endpoints. The host maps each type onto its own viz channel.
Variants
Implementations
Sourceimpl ConnectionType
impl ConnectionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.