#[repr(i32)]pub enum ConstraintKind {
Unspecified = 0,
AtomPair = 1,
Angle = 2,
Dihedral = 3,
}Expand description
Geometric relation a constraint pins; the count of ConstraintAtoms follows from the kind (AtomPair=2, Angle=3, Dihedral=4). Mirrors puzzle_setup::ConstraintKind.
Variants
Implementations
Sourceimpl ConstraintKind
impl ConstraintKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.