#[repr(i32)]pub enum ParamType {
Unspecified = 0,
Int = 1,
Float = 2,
Bool = 3,
String = 4,
Enum = 5,
Vec3 = 6,
}Expand description
Closed type set for parameter values. Residue / entity / range references are NOT here - they travel via DispatchContext.
Variants
Unspecified = 0
Int = 1
Float = 2
Bool = 3
String = 4
Enum = 5
encoded on the wire as string_value, validated by EnumValues constraint
Vec3 = 6
Implementations
Sourceimpl ParamType
impl ParamType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.