pub struct Connection {
pub type: i32,
pub a: Option<AtomEnd>,
pub b: Option<AtomEnd>,
pub magnitude: Option<f32>,
}Expand description
A generic structural connection between two endpoints. magnitude carries
clash severity (LJ fa_rep); unset for hbond/disulfide.
Fields
type: i32a: Option<AtomEnd>b: Option<AtomEnd>magnitude: Option<f32>Implementations
Sourceimpl Connection
impl Connection
Sourcepub fn type(&self) -> ConnectionType
pub fn type(&self) -> ConnectionType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ConnectionType)
pub fn set_type(&mut self, value: ConnectionType)
Sets type to the provided enum value.