pub struct ExposedHydrophobicReport {
pub exposed: Vec<ResidueRef>,
}Expand description
Payload of the exposed_hydrophobics query. Each entry is a residue the
detector flagged as an exposed hydrophobic. Empty exposed = none / clear.
Fields
exposed: Vec<ResidueRef>Trait Implementations
Sourceimpl Clone for ExposedHydrophobicReport
impl Clone for ExposedHydrophobicReport
Sourcefn clone(&self) -> ExposedHydrophobicReport
fn clone(&self) -> ExposedHydrophobicReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExposedHydrophobicReport
impl Debug for ExposedHydrophobicReport
Sourceimpl Default for ExposedHydrophobicReport
impl Default for ExposedHydrophobicReport
Sourceimpl Message for ExposedHydrophobicReport
impl Message for ExposedHydrophobicReport
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ExposedHydrophobicReport
impl PartialEq for ExposedHydrophobicReport
Sourcefn eq(&self, other: &ExposedHydrophobicReport) -> bool
fn eq(&self, other: &ExposedHydrophobicReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExposedHydrophobicReport